"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.runCommand = exports.getCommandAndArgvFromCli = exports.commandToFunction = exports.aliasToCommand = exports.isAlias = void 0;

var _commandLineCommands = _interopRequireDefault(require("command-line-commands"));

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isAlias = command => Object.keys(_constants.aliases).includes(command);

exports.isAlias = isAlias;

const aliasToCommand = alias => _constants.aliases[alias];

exports.aliasToCommand = aliasToCommand;

const commandToFunction = command => {
  command = command || _constants.defaultCommand;

  if (isAlias(command)) {
    command = aliasToCommand(command);
  }

  return _constants.commandsMap[command];
};

exports.commandToFunction = commandToFunction;

const getCommandAndArgvFromCli = () => {
  const {
    command,
    argv
  } = (0, _commandLineCommands.default)(_constants.availableCommandsList);
  return {
    command,
    argv
  };
};

exports.getCommandAndArgvFromCli = getCommandAndArgvFromCli;

const runCommand = (command, argv) => {
  const commandFunction = commandToFunction(command);
  return commandFunction(argv);
};

exports.runCommand = runCommand;