"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.exit = exports.validateUserConfig = exports.validateSeederTemplatePath = exports.validateSeedersFolderName = exports.getObjectWithSelectedKeys = exports.getFolderNameFromPath = exports.normalizeSeederFileName = exports.normalizeSeederName = void 0;

var _lodash = require("lodash");

var _config = _interopRequireDefault(require("../config"));

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const normalizeSeederName = name => (0, _lodash.upperFirst)((0, _lodash.camelCase)(name));

exports.normalizeSeederName = normalizeSeederName;

const normalizeSeederFileName = name => `${(0, _lodash.kebabCase)(name)}.seeder.js`;

exports.normalizeSeederFileName = normalizeSeederFileName;

const getFolderNameFromPath = path => path.substring(path.lastIndexOf('/') + 1);

exports.getFolderNameFromPath = getFolderNameFromPath;

const getObjectWithSelectedKeys = (obj, keys) => {
  const newObj = {};
  Object.keys(obj).forEach(k => {
    if (keys.includes(k)) {
      newObj[k] = obj[k];
    }
  });
  return newObj;
};

exports.getObjectWithSelectedKeys = getObjectWithSelectedKeys;

const validateSeedersFolderName = name => typeof name === 'string' && (0, _lodash.trim)(name).length >= 3;

exports.validateSeedersFolderName = validateSeedersFolderName;

const validateSeederTemplatePath = name => typeof name === 'string' && (0, _lodash.trim)(name).length >= 6;

exports.validateSeederTemplatePath = validateSeederTemplatePath;

const validateUserConfig = () => {
  const {
    userConfigExists
  } = _config.default;

  if (!userConfigExists) {
    throw new Error('Must contain md-seed-config.js at the project root. run `md-seed init` to create the config file.');
  }
};

exports.validateUserConfig = validateUserConfig;

const exit = error => {
  if (error && error.message && error.message !== 'exit') {
    console.error(error);
    process.exit(_constants.ExitCodes.Error);
  } else {
    process.exit(_constants.ExitCodes.Success);
  }
};

exports.exit = exit;